/*
  Copyright (C) MOXA Inc. All rights reserved.
  This software is distributed under the terms of the
  MOXA License.  See the file COPYING-MOXA for details.
*/

#include <cellular_modem.h>
#include <unistd.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <debug.h>

/*
 * Print usage routines
 */
static int usage(void)
{
	fprintf(stderr,
		"Usage:egprscmd <option> \n\
	       	-a[pin auth]<pin number> \n\
		-b[query sim] \n\
		-c[connect]<NULL||username:password> \n\
		-d[disconnect] \n\
		-e[del sms]<index>\n\
		-f[send file sms]<file path> \n\
		-g[diagnose] \n\
		-h[help] \n\
		-i[display imsi] \n\
		-j[gprs reconnect] \n\
		-l[lock]<pin number> \n\
		-m[send text sms]<phone:text:textlength> \n\
		-n[change pin]<old pin>:<new pin>\n\
		-o[reset]\n\
	       	-p[puk auth]<puk number><new pin number>\n\
		-r[read sms]<index>\n\
		-s[gprs status]\n\
		-t[at command]<\"at command\">\n\
		-u[unlock]<pin number> \n");
	return 1;
}
int main(int argc, char *argv[])
{
	static int options ;
 	extern char *optarg ;

	if(argc<=1)
		usage() ;

	/* parse arguments */
	while((options=getopt(argc,argv,"c:bdhgsa:l:u:n:p:ijm:f:r:e:t:o"))!=-1) {
	       	switch(options) {
			case 'b':
				PDEBUG("do query sim status") ;
				return do_sim_status(optarg) ;
			case 'c':
				PDEBUG("do connection") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return do_connection(optarg) ;
			case 'd':
				PDEBUG("do disconnection") ;
				return do_disconnection() ;
			case 's':
				PDEBUG("do connection status") ;
				return do_connection_status() ;
			case 'g':
				PDEBUG("do diagnose") ;
				return do_gprs_diagnose() ;
			case 'a':
				PDEBUG("do pin authentication") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return do_pin_authentication(optarg) ;
			case 'l':
				PDEBUG("do_sim_lock") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return do_sim_lock(optarg) ;
			case 'u':
				PDEBUG("do_sim_unlock") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return do_sim_unlock(optarg) ;
			case 'n':
				PDEBUG("renew_pin_number") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return renew_pin_number(optarg) ;
			case 'p':
				PDEBUG("do_puk_authentication") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return do_puk_authentication(optarg) ;
			case 'i':
				PDEBUG("display_imsi") ;
				return display_imsi() ;
			case 'j':
				PDEBUG("do_reconnection") ;
				return do_reconnection() ;
			case 'm':
				PDEBUG("send_sms_by_text") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return send_sms_by_text(optarg) ;
			case 'f':
				PDEBUG("send_sms_by_file") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return send_sms_by_file(optarg) ;
			case 'r':
				PDEBUG("read_sms_text_mode") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return read_sms_text_mode(optarg) ;
			case 'e':
				PDEBUG("delete_sms") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return delete_sms(optarg) ;
			case 't':
				PDEBUG("send_at_command") ;
				PDEBUG("with arg: %s\n",optarg) ;
				return send_at_command(optarg) ;
			case 'o':
				PDEBUG("do_reset") ;
				return do_reset() ;
			case 'h':
				usage() ;
				return 1 ; /* print help without process others opts */
			default:
				usage() ;
				return 1 ; /* print help without process others opts */
		}
	}

	return 0 ;
}
