/*
  Copyright (C) MOXA Inc. All rights reserved.
  This software is distributed under the terms of the
  MOXA License.  See the file COPYING-MOXA for details.
*/


/*
 * This is a example program to show how to detect the USB/CF storage plugin or
 * unplug. And check it mounts OK or fail.
 *
 * History:
 * Date		Author			Comment
 * 03-08-2006	Victor Yu.		Create it.
 */
#include	<stdio.h>
#include	<stdlib.h>
#include	<sys/statfs.h>
#include    <string.h>

#include	"usbcf.h"

#define BUFFER_SIZE		128

int	CFFree()
{
	struct statfs s;
	long blocks_used;
	long blocks_percent_used;

	if (statfs( "/mnt/hda", &s) != 0) 
		return -1;

	if (s.f_blocks > 0) 
		return s.f_bavail*s.f_bsize;

	return -1;
}

// input: int num	- want to check USB storage number
// 			  you must be 0 or 1
int 	USBFree( int num)
{
	struct statfs s;
	long blocks_used;
	long blocks_percent_used;
	char *mount="/mnt/sda";

	mount[7]+= num;

	if (statfs( mount, &s) != 0) 
		return -1;

	if (s.f_blocks > 0) 
		return s.f_bavail*s.f_bsize;

	return -1;
}

int	CheckCF()
{
	char	buffer[BUFFER_SIZE];
	char	str[BUFFER_SIZE];

	FILE	*f;

	// now check the CF plugin or not
	f = fopen("/proc/ide/hda", "r");
	if ( f == NULL )
		return STORAGE_UNPLUG;
	fclose(f);

	// now check mount OK or fail
	f = fopen("/proc/mounts", "r");
	if ( f == NULL )
		return STORAGE_PLUGIN;
	while ( fgets(buffer, BUFFER_SIZE, f) ) {
		sscanf(buffer, "%s", str);
		if ( strcmp(str, "/dev/hda1") == 0 ) {
			fclose(f);
			return STORAGE_MOUNT;
		}
	}
	fclose(f);
	return STORAGE_PLUGIN;
}

// input: int num	- want to check USB storage number
// 			  you must be 0 or 1
int	CheckUSB(int num)
{
	char	buffer[BUFFER_SIZE];
	char	str[BUFFER_SIZE];
	char	str1[BUFFER_SIZE];

	FILE	*f;
	char	fname[128], *ptr;

	// now check the USB plugin or not
	sprintf(fname, "/proc/scsi/usb-storage-%d/%d", num, num);
	f = fopen(fname, "r");
	if ( f == NULL )
		return STORAGE_UNPLUG;
	while ( fgets(buffer, BUFFER_SIZE, f) ) {
		sscanf(buffer, "%s %s", str, str1);
		if ( strcmp(str, "Attached:") == 0 ) {
			if ( strcmp(str1, "No") == 0 ) {
				fclose(f);
				return STORAGE_UNPLUG;
			}
			break;
		}
	}
	fclose(f);

	// now check mount OK or fail
	f = fopen("/proc/mounts", "r");
	if ( f == NULL )
		return STORAGE_PLUGIN;
	if ( num == 0 )
		strcpy(str1, "/dev/sda1");
	else
		strcpy(str1, "/dev/sdb1");
	while ( fgets(buffer, BUFFER_SIZE, f) ) {
		sscanf(buffer, "%s", str);
		if ( strcmp(str, str1) == 0 ) {
			fclose(f);
			return STORAGE_MOUNT;
		}
	}
	fclose(f);
	return STORAGE_PLUGIN;
}

